"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeQuery = exports.generateFileName = void 0;
const path_1 = __importDefault(require("path"));
const types_1 = require("./types");
/**
 * Generate the name of the processed image. The name generated follows the
 *  format: <imgName>,<operation>-<value>.<filetype>
 * Example: image1,height-100,width-200.png
 * @param imgName
 * @param queryParams
 * @returns
 */
function generateFileName(originalName, queryParams) {
    const { format } = queryParams, operations = __rest(queryParams, ["format"]);
    const imgFormat = format ? `.${format}` : path_1.default.extname(originalName);
    let newName = originalName.split('.')[0];
    // Concat operations and values in the name
    newName += Object.entries(operations)
        .sort((a, b) => a[0].localeCompare(b[0]))
        .reduce((acc, curr) => {
        acc += `,${curr[0]}-${curr[1]}`;
        return acc;
    }, '');
    // Add file format
    newName += imgFormat;
    return newName;
}
exports.generateFileName = generateFileName;
function normalizeQuery(params) {
    // Remove not allowed params
    const normalizedParams = Object.fromEntries(Object.entries(params).filter(([attr, _]) => attr in types_1.QueryParamsEnum));
    if ((normalizedParams.width && isNaN(normalizedParams.width)) ||
        (normalizedParams.height && isNaN(normalizedParams.height))) {
        throw new Error('Erro normalizing query!');
    }
    if (normalizedParams.width) {
        normalizedParams.width = Number(params.width);
    }
    if (normalizedParams.height) {
        normalizedParams.height = Number(params.height);
    }
    return normalizedParams;
}
exports.normalizeQuery = normalizeQuery;
