"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processMiddleware = void 0;
const path_1 = __importDefault(require("path"));
const helpers_1 = require("../helpers");
const image_transformer_1 = require("../image-transformer");
function processMiddleware(options) {
    return function (req, res, next) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const queryParams = req.query;
                const imgName = req.params.id;
                const normalizedQuery = (0, helpers_1.normalizeQuery)(queryParams);
                const newImgName = (0, helpers_1.generateFileName)(imgName, normalizedQuery);
                const newImgFormat = path_1.default.extname(newImgName).split('.')[1];
                const storage = options.storage;
                // Check if the processed image already exist in storage
                if (yield storage.exists(newImgName)) {
                    const image = yield storage.fetch(newImgName);
                    if (!image)
                        return errorResponse(res, 'Error fetching processed image.');
                    return successResponse(res, image, newImgFormat);
                }
                // Get the image from storage
                const image = yield storage.fetch(imgName);
                if (!image) {
                    return errorResponse(res, 'Image not found.');
                }
                // Process the image
                const transformedImage = yield new image_transformer_1.ImageTransformer().transform(image, normalizedQuery);
                // Save the image
                storage.save(newImgName, transformedImage);
                return successResponse(res, transformedImage, newImgFormat);
            }
            catch (err) {
                next(err);
            }
            finally {
                next();
            }
        });
    };
}
exports.processMiddleware = processMiddleware;
function successResponse(res, file, format) {
    res.set('Content-Type', `image/${format}`);
    return res.status(200).send(file);
}
function errorResponse(res, message) {
    return res.status(500).json({ error: message });
}
