"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiskStorage = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const multer_1 = __importDefault(require("multer"));
class DiskStorage {
    constructor(options) {
        this.dest = '';
        this.dest = options.dest;
    }
    save(id, image) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const imagePath = path_1.default.resolve(this.dest, id);
                yield fs_1.default.promises.writeFile(imagePath, image);
                return true;
            }
            catch (err) {
                throw new Error(`An error occurred during saving the image: ${err}`);
            }
        });
    }
    fetch(id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const imagePath = path_1.default.resolve(this.dest, id);
                return fs_1.default.promises.readFile(imagePath);
            }
            catch (err) {
                throw new Error(`An error occurred during getting the image: ${err}`);
            }
        });
    }
    exists(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const imagePath = path_1.default.resolve(this.dest, id);
            return yield fs_1.default.promises.stat(imagePath).then(() => true, () => false);
        });
    }
    getMulterStorage() {
        return multer_1.default.diskStorage({
            destination: path_1.default.resolve(this.dest),
            filename: (req, file, cb) => __awaiter(this, void 0, void 0, function* () {
                cb(null, file.originalname);
            }),
        });
    }
}
exports.DiskStorage = DiskStorage;
