"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3Storage = void 0;
const client_s3_1 = require("@aws-sdk/client-s3");
const lib_storage_1 = require("@aws-sdk/lib-storage");
const multer_s3_1 = __importDefault(require("multer-s3"));
class S3Storage {
    constructor(options) {
        this.bucketName = options.bucketName;
        this.s3Client = new client_s3_1.S3Client({
            region: options.region,
            credentials: {
                accessKeyId: options.accessKeyId,
                secretAccessKey: options.secretAccessKey,
            },
        });
    }
    save(id, image) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const params = {
                    Key: id,
                    Bucket: this.bucketName,
                    Body: image,
                };
                const upload = new lib_storage_1.Upload({
                    client: this.s3Client,
                    params: params,
                });
                yield upload.done();
                return true;
            }
            catch (err) {
                return false;
            }
        });
    }
    fetch(id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const params = {
                    Key: id,
                    Bucket: this.bucketName,
                };
                const response = yield this.s3Client.send(new client_s3_1.GetObjectCommand(params));
                const stream = response.Body;
                return new Promise((resolve, reject) => {
                    const chunks = [];
                    stream.on('data', (chunk) => chunks.push(chunk));
                    stream.once('end', () => resolve(Buffer.concat(chunks)));
                    stream.once('error', reject);
                });
            }
            catch (err) {
                return undefined;
            }
        });
    }
    exists(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = {
                Key: id,
                Bucket: this.bucketName,
            };
            const response = yield this.s3Client
                .send(new client_s3_1.HeadObjectCommand(params))
                .then(() => true, (err) => {
                return false;
            });
            return response;
        });
    }
    getMulterStorage() {
        return (0, multer_s3_1.default)({
            s3: this.s3Client,
            bucket: this.bucketName,
            contentType: multer_s3_1.default.AUTO_CONTENT_TYPE,
            acl: 'public-read',
            key: (req, file, cb) => __awaiter(this, void 0, void 0, function* () {
                cb(null, file.originalname);
            }),
        });
    }
}
exports.S3Storage = S3Storage;
